==> 2.9.zip: piwigo/language/gu_IN/common.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2016 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: ગુજરાતી[IN]
Version: auto
Language URI: http://piwigo.org/ext/extension_view.php?eid=767
Author: Piwigo team
Author URI: http://piwigo.org
*/
$lang_info['language_name'] = 'ગુજરાતી';
$lang_info['country'] = 'હિન્દુસ્તાન';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'gu';
$lang_info['zero_plural'] = true;

$lang['Date'] = 'તારીખ';
$lang['day'][0] = 'રવિવાર';
$lang['day'][1] = 'સોમવાર';
$lang['day'][2] = 'મંગળવાર';
$lang['day'][3] = 'બુધવાર';
$lang['day'][4] = 'ગુરુવાર';
$lang['day'][5] = 'શુક્રવાર';
$lang['day'][6] = 'શનિવાર';
$lang['month'][10] = 'ઑક્ટ્બર';
$lang['month'][11] = 'નવેમ્બર';
$lang['month'][12] = 'ડિસેમ્બર';
$lang['month'][1] = 'જાન્યુઆરી';
$lang['month'][2] = 'ફેબ્રુઆરી';
$lang['month'][3] = 'માર્ચ';
$lang['month'][4] = 'એપ્રિલ';
$lang['month'][5] = 'મે';
$lang['month'][6] = 'જૂન';
$lang['month'][7] = 'જુલાઈ';
$lang['month'][8] = 'ઑગસ્ટ';
$lang['month'][9] = 'સપ્ટેમ્બર';
$lang['View'] = 'જુઓ';
$lang['Webmaster'] = 'વેબમાસ્ટર';
$lang['Website'] = 'વેબસાઇટ';
$lang['Welcome'] = 'સ્વાગત';
$lang['Welcome to your Piwigo photo gallery!'] = 'પીવીગો ફોટો ગૅલરી મા તમારૂ સ્વાગત છે';
$lang['Yes'] = 'હા';
$lang['Your website URL is invalid'] = 'તમારુ આપેલુ URL માન્ય નથી';
$lang['add this photo to your favorites'] = 'આ ફોટો ની તમારા ફૅવોરીત મા ઉમેરો';
$lang['all'] = 'બધા';
$lang['ascending'] = 'ચડતા';
$lang['chronology_monthly_calendar'] = 'માસિક કૅલેન્ડર';
$lang['descending'] = 'ઉતરતા';
$lang['display most recent photos'] = 'હાલ ના નાવા ફોટો બતાવો';
$lang['display only recently posted photos'] = 'હાલ મા પોસ્ટ કરેલા ફોટો બતાવો';
$lang['display photos linked to this tag'] = 'આ ટૅગ થી જોડાઈલા ફોટો બતાવો';
$lang['display recently updated albums'] = 'હાલ મા સુધારેલા આલ્બમ બતાવો';
$lang['edit'] = 'ફેરફાર કરો';
$lang['guest'] = 'મહેમાન';
$lang['login mustn\'t end with a space character'] = 'લોગિન સ્પેસ થી ચાલુ ના થઈ શકે';
$lang['login mustn\'t start with a space character'] = 'લોગિન સ્પેસ થી અંત ના થઈ શકે';
$lang['mandatory'] = 'ફરજિયાત';
$lang['obligatory'] = 'ફરજિયાત';
$lang['photo'] = 'ફોટો';
$lang['search'] = 'શોધો';
$lang['square'] = 'ચોરસ';
$lang['the beginning'] = 'શુરુઆત';
$lang['this email address is already in use'] = 'આ ઈમેલ અડ્રેસ પેહલા થી વપરાશ મા છે';
$lang['this login is already used'] = 'આ લોગિન પેહલા થી વપરાશ મા છે';
$lang['today'] = 'આજે';
$lang['wrong date'] = 'ખોટી તારીખ';
$lang['set as album representative'] = 'થંબનેલ ની જેમ મુકો ';
$lang['thumb'] = 'થંબનેલ';
$lang['slideshow'] = 'સ્લાઇડ શો';
$lang['small'] = 'નાનું';
$lang['stop the slideshow'] = 'સ્લાઇડ શો બંધ કરો';
$lang['xsmall'] = 'વધારે નાનું';
$lang['xxlarge'] = 'વિશાળ';
$lang['xlarge'] = 'વધારે મોટું';
$lang['useful when password forgotten'] = 'કામ નુ અગર પાસવર્ડ ભૂલી ગયા હોઇ તો';
$lang['the username must be given'] = 'યૂજ઼ર નેમ નાખવુ જરૂરી છે';

==> 14.5.0.zip: piwigo/language/gu_IN/common.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
/*
Language Name: ગુજરાતી[IN]
Version: auto
Language URI: http://piwigo.org/ext/extension_view.php?eid=767
Author: Piwigo team
Author URI: http://piwigo.org
*/
$lang_info['language_name'] = 'ગુજરાતી';
$lang_info['country'] = 'હિન્દુસ્તાન';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'gu';
$lang_info['zero_plural'] = true;

$lang['Date'] = 'તારીખ';
$lang['day'][0] = 'રવિવાર';
$lang['day'][1] = 'સોમવાર';
$lang['day'][2] = 'મંગળવાર';
$lang['day'][3] = 'બુધવાર';
$lang['day'][4] = 'ગુરુવાર';
$lang['day'][5] = 'શુક્રવાર';
$lang['day'][6] = 'શનિવાર';
$lang['month'][10] = 'ઑક્ટ્બર';
$lang['month'][11] = 'નવેમ્બર';
$lang['month'][12] = 'ડિસેમ્બર';
$lang['month'][1] = 'જાન્યુઆરી';
$lang['month'][2] = 'ફેબ્રુઆરી';
$lang['month'][3] = 'માર્ચ';
$lang['month'][4] = 'એપ્રિલ';
$lang['month'][5] = 'મે';
$lang['month'][6] = 'જૂન';
$lang['month'][7] = 'જુલાઈ';
$lang['month'][8] = 'ઑગસ્ટ';
$lang['month'][9] = 'સપ્ટેમ્બર';
$lang['View'] = 'જુઓ';
$lang['Webmaster'] = 'વેબમાસ્ટર';
$lang['Website'] = 'વેબસાઇટ';
$lang['Welcome'] = 'સ્વાગત';
$lang['Welcome to your Piwigo photo gallery!'] = 'પીવીગો ફોટો ગૅલરી મા તમારૂ સ્વાગત છે';
$lang['Yes'] = 'હા';
$lang['Your website URL is invalid'] = 'તમારુ આપેલુ URL માન્ય નથી';
$lang['add this photo to your favorites'] = 'આ ફોટો ની તમારા ફૅવોરીત મા ઉમેરો';
$lang['all'] = 'બધા';
$lang['ascending'] = 'ચડતા';
$lang['chronology_monthly_calendar'] = 'માસિક કૅલેન્ડર';
$lang['descending'] = 'ઉતરતા';
$lang['display most recent photos'] = 'હાલ ના નાવા ફોટો બતાવો';
$lang['display only recently posted photos'] = 'હાલ મા પોસ્ટ કરેલા ફોટો બતાવો';
$lang['display photos linked to this tag'] = 'આ ટૅગ થી જોડાઈલા ફોટો બતાવો';
$lang['display recently updated albums'] = 'હાલ મા સુધારેલા આલ્બમ બતાવો';
$lang['edit'] = 'ફેરફાર કરો';
$lang['guest'] = 'મહેમાન';
$lang['login mustn\'t end with a space character'] = 'લોગિન સ્પેસ થી ચાલુ ના થઈ શકે';
$lang['login mustn\'t start with a space character'] = 'લોગિન સ્પેસ થી અંત ના થઈ શકે';
$lang['mandatory'] = 'ફરજિયાત';
$lang['obligatory'] = 'ફરજિયાત';
$lang['photo'] = 'ફોટો';
$lang['search'] = 'શોધો';
$lang['square'] = 'ચોરસ';
$lang['the beginning'] = 'શુરુઆત';
$lang['this email address is already in use'] = 'આ ઈમેલ અડ્રેસ પેહલા થી વપરાશ મા છે';
$lang['this login is already used'] = 'આ લોગિન પેહલા થી વપરાશ મા છે';
$lang['today'] = 'આજે';
$lang['wrong date'] = 'ખોટી તારીખ';
$lang['set as album representative'] = 'થંબનેલ ની જેમ મુકો ';
$lang['thumb'] = 'થંબનેલ';
$lang['slideshow'] = 'સ્લાઇડ શો';
$lang['small'] = 'નાનું';
$lang['stop the slideshow'] = 'સ્લાઇડ શો બંધ કરો';
$lang['xsmall'] = 'વધારે નાનું';
$lang['xxlarge'] = 'વિશાળ';
$lang['xlarge'] = 'વધારે મોટું';
$lang['useful when password forgotten'] = 'કામ નુ અગર પાસવર્ડ ભૂલી ગયા હોઇ તો';
$lang['the username must be given'] = 'યૂજ઼ર નેમ નાખવુ જરૂરી છે';
